<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Autoloader.
 *
 * @class 		WP_OAuth_Integration_Autoloader
 * @version		0.1.0
 */
class WP_OAuth_Integration_Autoloader {

	/**
	 * Path to the includes directory.
	 *
	 * @var string
	 */
	private $include_path = '';

	/**
	 * The Constructor.
	 */
	public function __construct() {
		if ( function_exists( "__autoload" ) ) {
			spl_autoload_register( "__autoload" );
		}

		spl_autoload_register( array( $this, 'autoload' ) );

		$this->include_path = untrailingslashit( plugin_dir_path( WP_OAUTH_INTEGRATION_FILE ) ) . '/includes/lib/';
	}

	/**
	 * Take a class name and turn it into a file name.
	 *
	 * @param  string $class
	 * @return string
	 */
	private function get_file_name_from_class( $class ) {
		return 'class-' . str_replace( '_', '-', $class ) . '.php';
	}

	/**
	 * Include a class file.
	 *
	 * @param  string $path
	 * @return bool successful or not
	 */
	private function load_file( $path ) {
		if ( $path && is_readable( $path ) ) {
			include_once( $path );
			return true;
		}
		return false;
	}

	/**
	 * Auto-load WC classes on demand to reduce memory consumption.
	 *
	 * @param string $class
	 */
	public function autoload( $class ) {
		$class = strtolower( $class );
		$file  = $this->get_file_name_from_class( $class );
		$path  = '';

		if ( empty( $path ) || ( ! $this->load_file( $path . $file ) && strpos( $class, 'wp-oauth-integration_' ) === 0 ) ) {
			$this->load_file( $this->include_path . $file );
		}
	}
}

new WP_OAuth_Integration_Autoloader();
